==> haskell-tasty-kat-0.0.3-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-kat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-kat
version:              0.0.3
visibility:           public
id:                   tasty-kat-0.0.3-4iPtM0uiK1n5HSFOrIVVUz
key:                  tasty-kat-0.0.3-4iPtM0uiK1n5HSFOrIVVUz
license:              MIT
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/tasty-kat
synopsis:             Known Answer Tests (KAT) framework for tasty
description:
    Tests running from simple KATs file (different formats/helper supported)

category:             tasty-kat
abi:                  f5bad4a729ae12e5230cfdd0dabcb521
exposed:              True
exposed-modules:      Test.Tasty.KAT Test.Tasty.KAT.FileLoader
hidden-modules:       Test.Tasty.KAT.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/tasty-kat-0.0.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/tasty-kat-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/tasty-kat-0.0.3
hs-libraries:         HStasty-kat-0.0.3-4iPtM0uiK1n5HSFOrIVVUz
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    tasty-1.4.1-7wIh5zAM7Rm5Qj9S8oWkM

haddock-interfaces:   /usr/share/doc/haskell-tasty-kat/html/tasty-kat.haddock
haddock-html:         /usr/share/doc/haskell-tasty-kat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-kat-0.0.3-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-kat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-kat
version:              0.0.3
visibility:           public
id:                   tasty-kat-0.0.3-HZO7pqOLJ3e5h30RkNXBa6
key:                  tasty-kat-0.0.3-HZO7pqOLJ3e5h30RkNXBa6
license:              MIT
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/tasty-kat
synopsis:             Known Answer Tests (KAT) framework for tasty
description:
    Tests running from simple KATs file (different formats/helper supported)

category:             tasty-kat
abi:                  bc82e12aa453a8c7bc8aae01d1a93c59
exposed:              True
exposed-modules:      Test.Tasty.KAT Test.Tasty.KAT.FileLoader
hidden-modules:       Test.Tasty.KAT.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/tasty-kat-0.0.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/tasty-kat-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/tasty-kat-0.0.3
hs-libraries:         HStasty-kat-0.0.3-HZO7pqOLJ3e5h30RkNXBa6
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    tasty-1.4.1-ENdd2P1wkVZDpviRGa3elP

haddock-interfaces:   /usr/share/doc/haskell-tasty-kat/html/tasty-kat.haddock
haddock-html:         /usr/share/doc/haskell-tasty-kat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
